<?php

/**
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   Adressbook
 * @package    QuickTeam
 * @author     Philippe Vandenberghe <info@qt-cute.org>
 * @copyright  2008-2012 The PHP Group
 * @version    2.5 build:20110323
 */

session_start();
require_once('bin/qte_init.php');
if ( !$oVIP->CanView('V2') ) die(Error(11));

// ---------
// INITIALISE
// ---------
// Note: This returns pages of 100 items ($_SESSION[QT]['items_per_page'] replaced by 100)

$s = -1;
$label = -1; // add display name
QThttpvar('s label','int int');
if ( $s<0 ) die('Missing argument s');

include(Translate('qte_email.php'));

$strGroup = 'all';
$strOrder = 'lastname';
$strDirec = 'ASC';
$intLimit = 0;
$intPage  = 1;

// security check 1
if ( isset($_GET['group']) ) $strGroup = strip_tags($_GET['group']);
if ( isset($_GET['order']) ) $strOrder = strip_tags($_GET['order']);
if ( isset($_GET['dir']) ) $strDirec = strip_tags($_GET['dir']);
if ( isset($_GET['page']) ) $intPage = intval(strip_tags($_GET['page']));
if ( isset($_GET['view']) ) $_SESSION[QT]['viewmode'] = strip_tags($_GET['view']);

// security check 2 (no long argument)
if ( strlen($strGroup)>4 ) die('Invalid argument #group');
if ( strlen($strOrder)>12 ) die('Invalid argument #order');
if ( strlen($strDirec)>4 ) die('Invalid argument #dir');

$intLimit = ($intPage-1)*100;

$_SESSION[QT]['section'] = $s;

include('bin/qte_fn_sql.php');

$oSEC = new cSection($s);

if ( $oSEC->type==1 && !$oVIP->IsStaff() )
{
  // exit
  $oVIP->selfname = $L['Section'];
  $oVIP->exitname = ObjTrans('index','i',$_SESSION[QT]['index_name']);
  $oVIP->EndMessage(NULL,$L['R_staff'],$_SESSION[QT]['skin_dir'],0);
}
if ( $oSEC->type==2 && $oVIP->role=='V' )
{
  // exit
  $oVIP->selfname = $L['Section'];
  $oVIP->exitname = ObjTrans('index','i',$_SESSION[QT]['index_name']);
  $oVIP->EndMessage(NULL,$L['R_user'],$_SESSION[QT]['skin_dir'],0);
}

$oVIP->selfurl = 'qte_email.php';
$oVIP->selfname = $L['Section'].': '.$oSEC->name;

$strShowZ   = ''; if ( !$_SESSION[QT]['show_Z'] ) $strShowZ = ' AND u.status<>"Z"';

// COUNT Members

$strWhereGroup = '';
switch ($strGroup)
{
  case 'all': $strWhereGroup .= ' AND u.id>0'; Break;
  case '0':   $strWhereGroup .= ' AND '.FirstCharCase('u.username','a-z'); Break;
  default:    $strWhereGroup .= ' AND '.FirstCharCase('u.username','u').'="'.$strGroup.'"'; Break;
}
$oDB->Query('SELECT count(*) as countid FROM '.TABUSER.' u INNER JOIN '.TABS2U.' l ON l.userid=u.id WHERE l.sid='.$oSEC->id.$strShowZ.$strWhereGroup);
$row = $oDB->Getrow();
$intCount = (int)$row['countid'];

// --------
// Pager
// --------

$strPager = MakePager(Href().'?s='.$oSEC->id.'&group='.$strGroup,$intCount,100,$intPage);
if ( !empty($strPager) ) { $strPager = $L['Page'].$strPager; } else { $strPager=S; }
if ( $intCount<$oSEC->members ) $strPager = '<span class="small">'.$intCount.' '.$L['Selected_from'].' '.$oSEC->members.' '.strtolower($L['Users']).'</span>'.($strPager==S ? '' : ' | '.$strPager);

// --------
// HTML START Emails prection and java are not used because only staffs can access the page
// --------

$oHtml->scripts = array();
include('qte_p_header.php');

// Display description

if ( $_SESSION[QT]['section_descr']=='1' )
{
  $oSEC->descr .= (empty($oSEC->descr) ? '' : '<br />').'<span class="small">('.LangS('User',$oSEC->members).')</span>';
  $oSEC->ShowInfo('sectioninfo_left','sectioninfo','sectiondesc');
}

// Display letters bar

if ( $intCount>100 || isset($_GET['group']) ) echo '<table class="lettres" cellspacing="0"><tr class="lettres">',HtmlLettres($strGroup,$s,$L['All']),'</tr></table>',PHP_EOL;

// Display no member

if ( $intCount==0 )
{
  echo '<br />',$L['E_no_member'],'<br /><br />';
  include('qte_p_footer.php');
  exit;
}

// Display top pager

if ( $strPager )
{
echo '
<table class="hidden" cellspacing="0"><tr class="hidden"><td class="pager_zt">',$strPager,'</td></tr></table>
';
}
else
{
echo '<br />';
}

// --------
// Query members
// ----------
$strState  = 'u.id,u.title,u.firstname,u.midname,u.lastname,u.username,u.alias,u.privacy,u.emails FROM '.TABUSER.' u INNER JOIN '.TABS2U.' l ON l.userid=u.id WHERE l.sid='.$oSEC->id.$strShowZ.$strWhereGroup;
if ( substr($strOrder,0,2)!='u.' ) $strOrder = 'u.'.$strOrder;
if ( $strOrder=='u.fullname' ) $strOrder = 'u.lastname';
$oDB->Query( LimitSQL($strState,$strOrder.' '.$strDirec,$intLimit,100) );
// ----------

$arrUsersEmails = array(); // store id->fullname+emails (if email exists). Support several emails for a user.
$arrEmailsUsers = array(); // store email->fullname <email> (if email exists). This is the DISTINCT emails (email is the key)
                           // To display only the emails, use the array keys (Array values contains the labels+emails)
$i=0;
while ( $row=$oDB->Getrow() )
{
  if ( strlen($row['emails'])>5 )
  {
    $oUser = new cUser($row,true);  // privatise  
    $arrUsersEmails[] = $oUser->fullname.'&nbsp;&nbsp;<a class="small" href="mailto:'.strip_tags($oUser->emails).'" title="'.$oUser->fullname.'">'.$oUser->emails.'</a>'.(strstr($oUser->privacy,'emails') ? ' <span class="small">('.$L['Hidden'].')</span>' : '');
    $arr = explode(';',strip_tags($oUser->emails));
    foreach($arr as $str) $arrEmailsUsers[trim($str)] = trim($oUser->fullname).' <'.trim($str).'>';
    $i++;
  }
}

// Display members.

echo '<table class="data_t" cellspacing="0">',PHP_EOL;
echo '<tr class="data_o">',PHP_EOL;

$arrFLD = GetFLDs('0;emails;2;9',false);
$arrFLD['0']->class_th='colhd colhdfirst'; $arrFLD['0']->name = S;
$arrFLD['emails']->class_th='colhd';       $arrFLD['emails']->name = ObjTrans('field','emails');
$arrFLD['2']->class_th='colhd';            $arrFLD['2']->name = S;
$arrFLD['9']->class_th='colhd colhdlast';  $arrFLD['9']->name = S;

TableHeader($arrFLD,$intCount,"$oVIP->selfurl?s=$s&amp;page=1",$strOrder,$strDirec);

echo '</tr>',PHP_EOL;

echo '<tr class="data_o">
<td class="colct colfirst">&nbsp;</td>
<td class="colct" style="vertical-align:top">',sprintf($L['Emails_from'],$i,$intCount),'</td>
<td class="colct" style="vertical-align:top">',sprintf($L['Emails_dist_from'],count($arrEmailsUsers),$intCount),'</td>
<td class="colct collast">&nbsp;</td>
</tr>
';
echo '<tr class="data_o">
<td class="colhd colhdempty"></td>
<td class="colhd colhdempty"></td>
<td class="colhd colhdempty"></td>
<td class="colhd colhdempty"></td>
</tr>
';
echo '<tr class="data_o">
<td class="colct colfirst">&nbsp;</td>
<td class="colct" style="vertical-align:top">
',implode('<br />',$arrUsersEmails),'
</td>
<td class="colct" style="vertical-align:top">
<textarea class="small" rows="',(count($arrEmailsUsers)>20 ? '40' : '15'),'" cols="50">',($label>0 ? implode('; ',$arrEmailsUsers) : implode('; ',array_keys($arrEmailsUsers))),'</textarea>
<br />
<form method="get" id="add" action="',Href(),'">
<input type="hidden" name="s" value="',$s,'" />
<input type="checkbox" id="label" name="label" value="1" ',($label>0 ? QCHE : ''),'onchange="document.getElementById(\'add\').submit();" /><label for="label">',$L['Emails_label'],'</label>
<input type="submit" id="ok" name="ok" value="',$L['Ok'],'" />
</form>
<script type="text/javascript">document.getElementById("ok").style.display="none";</script>
</td>
<td class="colct collast">&nbsp;</td>
</tr>
';
echo '<tr class="data_o">
<td class="colft colftfirst"></td>
<td class="colft"></td>
<td class="colft"></td>
<td class="colft colftlast"></td>
</tr>
</table>
';

// --------
// Display bottom pager
// --------

if ( $strPager )
{
echo '
<table class="hidden" cellspacing="0"><tr class="hidden"><td class="pager_zb">',$strPager,'</td></tr></table>
';
}

echo '<p class="helpbox">',$L['Emails_help'],'</p>
';

// --------
// HTML END
// --------

include('qte_p_footer.php');